module GeostellarClient
  class User

    include Virtus.model

    attribute :id, Integer
    attribute :email, String
    attribute :phone, String
    attribute :first_name, String
    attribute :last_name, String
    attribute :street_address_1, String
    attribute :street_address_2, String
    attribute :city, String
    attribute :state, String
    attribute :zip_code, String
    attribute :password, String

    def self.find(id)
      response = HTTParty.get(
        find_url(id),
        { api_key: GeostellarClient.api_key }
      )
      new(JSON.parse(response.body))
    end

    def self.create(attrs)
      valid_attrs = User.new(attrs).attributes.reject { |k, v| v.nil? }
      options = {
        api_key: GeostellarClient.api_key,
        body: { user: valid_attrs },
      }

      response = HTTParty.post(api_url, options)

      if response.success?
        new(response.parsed_response)
      else
        message = response["errors"].join(', ')
        raise GeostellarClient::UserCreationError, message
      end
    end

    private

    def self.find_url(id)
      "#{api_url}/#{id}"
    end

    def self.api_url
      "#{GeostellarClient::BASE_API_URL}users"
    end

  end
end
